@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: atrhandler.c 2613 2007-08-13 07:13:30Z rousseau $
+ * $Id: atrhandler.c 2891 2008-04-21 13:14:46Z rousseau $
  */
 
 /**
@@ -156,22 +156,12 @@ short ATRDecodeAtr(PSMARTCARD_EXTENSION psExtension,
 			{
 				psExtension->CardCapabilities.AvailableProtocols |=
 					SCARD_PROTOCOL_T0;
-				psExtension->CardCapabilities.T0.BGT = 0;
-				psExtension->CardCapabilities.T0.BWT = 0;
-				psExtension->CardCapabilities.T0.CWT = 0;
-				psExtension->CardCapabilities.T0.CGT = 0;
-				psExtension->CardCapabilities.T0.WT = 0;
 			}
 			else
 				if (1 == T)
 				{
 					psExtension->CardCapabilities.AvailableProtocols |=
 						SCARD_PROTOCOL_T1;
-					psExtension->CardCapabilities.T1.BGT = 0;
-					psExtension->CardCapabilities.T1.BWT = 0;
-					psExtension->CardCapabilities.T1.CWT = 0;
-					psExtension->CardCapabilities.T1.CGT = 0;
-					psExtension->CardCapabilities.T1.WT = 0;
 				}
 				else
 					if (15 == T)
