@@ -4,7 +4,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: atrhandler.h 2151 2006-09-06 20:02:47Z rousseau $
+ * $Id: atrhandler.h 2891 2008-04-21 13:14:46Z rousseau $
  */
 
 /**
@@ -36,52 +36,13 @@ extern "C"
 		}
 		ATR;
 
-		DWORD ReadTimeout;
-
 		struct _CardCapabilities
 		{
 			UCHAR AvailableProtocols;
 			UCHAR CurrentProtocol;
 			UCHAR Convention;
-			USHORT ETU;
-
-			struct _PtsData
-			{
-				UCHAR F1;
-				UCHAR D1;
-				UCHAR I1;
-				UCHAR P1;
-				UCHAR N1;
-			}
-			PtsData;
-
-			struct _T1
-			{
-				USHORT BGT;
-				USHORT BWT;
-				USHORT CWT;
-				USHORT CGT;
-				USHORT WT;
-			}
-			T1;
-
-			struct _T0
-			{
-				USHORT BGT;
-				USHORT BWT;
-				USHORT CWT;
-				USHORT CGT;
-				USHORT WT;
-			}
-			T0;
-
 		}
 		CardCapabilities;
-
-		/*
-		 * PREADER_CONNECTION psReaderConnection;
-		 */
-
 	}
 	SMARTCARD_EXTENSION, *PSMARTCARD_EXTENSION;
 
