@@ -6,7 +6,7 @@
  * Copyright (C) 1999-2005
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debuglog.c 2633 2007-10-03 13:53:06Z rousseau $
+ * $Id: debuglog.c 2896 2008-04-22 09:20:00Z rousseau $
  */
 
 /**
@@ -44,10 +44,10 @@ static char LogSuppress = DEBUGLOG_LOG_ENTRIES;
 static char LogMsgType = DEBUGLOG_NO_DEBUG;
 static char LogCategory = DEBUG_CATEGORY_NOTHING;
 
-/* default level is a bit verbose to be backward compatible */
+/** default level is a bit verbose to be backward compatible */
 static char LogLevel = PCSC_LOG_INFO;
 
-static signed char LogDoColor = 0;	/* no color by default */
+static signed char LogDoColor = 0;	/**< no color by default */
 
 static void log_line(const int priority, const char *DebugBuffer);
 
@@ -123,7 +123,10 @@ static void log_line(const int priority, const char *DebugBuffer)
 				tmp.tv_sec--;
 				tmp.tv_usec += 1000000;
 			}
-			delta = tmp.tv_sec * 1000000 + tmp.tv_usec;
+			if (tmp.tv_sec < 100)
+				delta = tmp.tv_sec * 1000000 + tmp.tv_usec;
+			else
+				delta = 99999999;
 
 			fprintf(stderr, "%s%.8d%s %s%s%s\n", time_pfx, delta, time_sfx,
 				color_pfx, DebugBuffer, color_sfx);
