@@ -4,7 +4,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: dyn_generic.h 1651 2005-09-15 11:35:34Z rousseau $
+ * $Id: dyn_generic.h 2265 2006-12-03 13:17:42Z rousseau $
  */
 
 /**
@@ -22,7 +22,7 @@ extern "C"
 
 	int DYN_LoadLibrary(void **, char *);
 	int DYN_CloseLibrary(void **);
-	int DYN_GetAddress(void *, void **, char *);
+	int DYN_GetAddress(void *, void **, const char *);
 
 #ifdef __cplusplus
 }
