@@ -3,10 +3,10 @@
  *
  * Copyright (C) 2000
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 2004
+ * Copyright (C) 2004-2008
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: eventhandler.c 2714 2007-12-13 21:36:59Z rousseau $
+ * $Id: eventhandler.c 3030 2008-06-26 14:00:00Z rousseau $
  */
 
 /**
@@ -100,6 +100,10 @@ LONG EHInitializeEventStructures(void)
 
 LONG EHDestroyEventHandler(PREADER_CONTEXT rContext)
 {
+	int rv;
+	DWORD dwGetSize;
+	UCHAR ucGetData[1];
+
 	if (NULL == rContext->readerState)
 	{
 		Log1(PCSC_LOG_ERROR, "Thread never started (reader init failed?)");
@@ -119,19 +123,28 @@ LONG EHDestroyEventHandler(PREADER_CONTEXT rContext)
 
 	Log1(PCSC_LOG_INFO, "Stomping thread.");
 
-	do
+	/* kill the "polling" thread */
+	dwGetSize = sizeof(ucGetData);
+	rv = IFDGetCapabilities(rContext, TAG_IFD_POLLING_THREAD_KILLABLE,
+		&dwGetSize, ucGetData);
+
+	if ((IFD_SUCCESS == rv) && (1 == dwGetSize) && ucGetData[0])
 	{
-		/*
-		 * Wait 0.05 seconds for the child to respond
-		 */
-		SYS_USleep(50000);
+		Log1(PCSC_LOG_INFO, "Killing polling thread");
+		SYS_ThreadCancel(rContext->pthThread);
 	}
-	while (rContext->dwLockId == 0xFFFF);
+	else
+		Log1(PCSC_LOG_INFO, "Waiting polling thread");
+
+	/* wait for the thread to finish */
+	rv = SYS_ThreadJoin(rContext->pthThread, NULL);
+	if (rv)
+		Log2(PCSC_LOG_ERROR, "SYS_ThreadJoin failed: %s", strerror(rv));
+
 	/*
 	 * Zero out the public status struct to allow it to be recycled and
 	 * used again
 	 */
-
 	memset(rContext->readerState->readerName, 0,
 		sizeof(rContext->readerState->readerName));
 	memset(rContext->readerState->cardAtr, 0,
@@ -150,7 +163,8 @@ LONG EHDestroyEventHandler(PREADER_CONTEXT rContext)
 	return SCARD_S_SUCCESS;
 }
 
-LONG EHSpawnEventHandler(PREADER_CONTEXT rContext)
+LONG EHSpawnEventHandler(PREADER_CONTEXT rContext,
+	RESPONSECODE (*card_event)(DWORD))
 {
 	LONG rv;
 	DWORD dwStatus = 0;
@@ -190,12 +204,16 @@ LONG EHSpawnEventHandler(PREADER_CONTEXT rContext)
 	rContext->readerState->cardAtrLength = dwAtrLen;
 	rContext->readerState->cardProtocol = SCARD_PROTOCOL_UNDEFINED;
 
-	rv = SYS_ThreadCreate(&rContext->pthThread, THREAD_ATTR_DETACHED,
+	rContext->pthCardEvent = card_event;
+	rv = SYS_ThreadCreate(&rContext->pthThread, 0,
 		(PCSCLITE_THREAD_FUNCTION( ))EHStatusHandlerThread, (LPVOID) rContext);
-	if (rv == 1)
-		return SCARD_S_SUCCESS;
-	else
+	if (rv)
+	{
+		Log2(PCSC_LOG_ERROR, "SYS_ThreadCreate failed: %s", strerror(rv));
 		return SCARD_E_NO_MEMORY;
+	}
+	else
+		return SCARD_S_SUCCESS;
 }
 
 static void incrementEventCounter(struct pubReaderStatesList *readerState)
@@ -411,11 +429,6 @@ void EHStatusHandlerThread(PREADER_CONTEXT rContext)
 					rContext->readerState->readerState &= ~SCARD_SPECIFIC;
 					rContext->readerState->readerState &= ~SCARD_UNKNOWN;
 					rContext->readerState->readerState &= ~SCARD_SWALLOWED;
-
-					/*
-					 * Notify the card has been reset
-					 */
-					RFSetReaderEventState(rContext, SCARD_RESET);
 				}
 				else
 				{
@@ -453,16 +466,6 @@ void EHStatusHandlerThread(PREADER_CONTEXT rContext)
 			}
 		}
 
-		if (rContext->dwLockId == 0xFFFF)
-		{
-			/*
-			 * Exit and notify the caller
-			 */
-			rContext->dwLockId = 0;
-			SYS_ThreadDetach(rContext->pthThread);
-			SYS_ThreadExit(NULL);
-		}
-
 		/*
 		 * Sharing may change w/o an event pass it on
 		 */
@@ -474,7 +477,26 @@ void EHStatusHandlerThread(PREADER_CONTEXT rContext)
 			SYS_MMapSynchronize((void *) rContext->readerState, pageSize);
 		}
 
-		SYS_USleep(PCSCLITE_STATUS_POLL_RATE);
+		if (rContext->pthCardEvent)
+		{
+			int ret;
+
+			ret = rContext->pthCardEvent(rContext->dwSlot);
+			if (IFD_NO_SUCH_DEVICE == ret)
+				SYS_USleep(PCSCLITE_STATUS_POLL_RATE);
+		}
+		else
+			SYS_USleep(PCSCLITE_STATUS_POLL_RATE);
+
+		if (rContext->dwLockId == 0xFFFF)
+		{
+			/*
+			 * Exit and notify the caller
+			 */
+			Log1(PCSC_LOG_INFO, "Die");
+			rContext->dwLockId = 0;
+			SYS_ThreadExit(NULL);
+		}
 	}
 }
 
