@@ -7,7 +7,7 @@
  *  Toni Andjelkovic <toni@soth.at>
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *
- * $Id: hotplug_libusb.c 2611 2007-08-08 14:35:57Z rousseau $
+ * $Id: hotplug_libusb.c 2918 2008-04-30 07:33:58Z rousseau $
  */
 
 /**
@@ -62,7 +62,7 @@ extern int HPForceReaderPolling;
 /* values of ifdCapabilities bits */
 #define IFD_GENERATE_HOTPLUG 1
 
-/*
+/**
  * keep track of drivers in a dynamically allocated array
  */
 static struct _driverTracker
@@ -77,24 +77,24 @@ static struct _driverTracker
 } *driverTracker = NULL;
 #define DRIVER_TRACKER_SIZE_STEP 8
 
-/*
+/**
  * keep track of PCSCLITE_MAX_READERS_CONTEXTS simultaneous readers
  */
 static struct _readerTracker
 {
 	char status;
-	char bus_device[BUS_DEVICE_STRSIZE];	/* device name */
-	char *fullName;	/* full reader name (including serial number) */
+	char bus_device[BUS_DEVICE_STRSIZE];	/**< device name */
+	char *fullName;	/**< full reader name (including serial number) */
 } readerTracker[PCSCLITE_MAX_READERS_CONTEXTS];
 
-LONG HPReadBundleValues(void);
-LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
+static LONG HPReadBundleValues(void);
+static LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
 	struct _driverTracker *driver);
-LONG HPRemoveHotPluggable(int reader_index);
+static LONG HPRemoveHotPluggable(int reader_index);
 static void HPRescanUsbBus(void);
 static void HPEstablishUSBNotifications(void);
 
-LONG HPReadBundleValues(void)
+static LONG HPReadBundleValues(void)
 {
 	LONG rv;
 	DIR *hpDir;
@@ -243,7 +243,7 @@ LONG HPReadBundleValues(void)
 	return rv;
 }
 
-void HPRescanUsbBus(void)
+static void HPRescanUsbBus(void)
 {
 	int i, j;
 	struct usb_bus *bus;
@@ -313,7 +313,7 @@ void HPRescanUsbBus(void)
 	 */
 	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
 	{
-#if defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__)
+#if defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__DragonFly__)
 		int fd;
 		char filename[BUS_DEVICE_STRSIZE];
 
@@ -378,7 +378,7 @@ void HPRescanUsbBus(void)
 	}
 }
 
-void HPEstablishUSBNotifications(void)
+static void HPEstablishUSBNotifications(void)
 {
 	int i, do_polling;
 
@@ -467,20 +467,20 @@ LONG HPStopHotPluggables(void)
 	return 0;
 }
 
-LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
+static LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
 	struct _driverTracker *driver)
 {
 	int i;
 	char deviceName[MAX_DEVICENAME];
 
-	SYS_MutexLock(&usbNotifierMutex);
-
 	Log2(PCSC_LOG_INFO, "Adding USB device: %s", bus_device);
 
 	snprintf(deviceName, sizeof(deviceName), "usb:%04x/%04x:libusb:%s",
 		dev->descriptor.idVendor, dev->descriptor.idProduct, bus_device);
 	deviceName[sizeof(deviceName) -1] = '\0';
 
+	SYS_MutexLock(&usbNotifierMutex);
+
 	/* find a free entry */
 	for (i=0; i<PCSCLITE_MAX_READERS_CONTEXTS; i++)
 	{
@@ -492,6 +492,7 @@ LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
 	{
 		Log2(PCSC_LOG_ERROR,
 			"Not enough reader entries. Already found %d readers", i);
+		SYS_MutexUnLock(&usbNotifierMutex);
 		return 0;
 	}
 
@@ -530,7 +531,7 @@ LONG HPAddHotPluggable(struct usb_device *dev, const char bus_device[],
 	return 1;
 }	/* End of function */
 
-LONG HPRemoveHotPluggable(int reader_index)
+static LONG HPRemoveHotPluggable(int reader_index)
 {
 	SYS_MutexLock(&usbNotifierMutex);
 
@@ -549,7 +550,7 @@ LONG HPRemoveHotPluggable(int reader_index)
 	return 1;
 }	/* End of function */
 
-/*
+/**
  * Sets up callbacks for device hotplug events.
  */
 ULONG HPRegisterForHotplugEvents(void)
