@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: ifdwrapper.c 2660 2007-10-18 09:11:23Z rousseau $
+ * $Id: ifdwrapper.c 2944 2008-05-12 08:36:21Z rousseau $
  */
 
 /**
@@ -14,6 +14,7 @@
  * @brief This wraps the dynamic ifdhandler functions.
  */
 
+#include <errno.h>
 #include "config.h"
 #include "misc.h"
 #include "pcscd.h"
@@ -24,15 +25,14 @@
 #include "atrhandler.h"
 #include "dyn_generic.h"
 #include "sys_generic.h"
-#include "hotplug.h"
+#include "utils.h"
 
 #undef PCSCLITE_STATIC_DRIVER
 
-/*
- * Function: IFDSetPTS Purpose : To set the protocol type selection (PTS).
+/**
+ * Set the protocol type selection (PTS).
  * This function sets the appropriate protocol to be used on the card.
  */
-
 LONG IFDSetPTS(PREADER_CONTEXT rContext, DWORD dwProtocol, UCHAR ucFlags,
 	UCHAR ucPTS1, UCHAR ucPTS2, UCHAR ucPTS3)
 {
@@ -109,11 +109,9 @@ LONG IFDSetPTS(PREADER_CONTEXT rContext, DWORD dwProtocol, UCHAR ucFlags,
 	return rv;
 }
 
-/*
- * Function: IFDOpenIFD Purpose : This function opens a communication
- * channel to the IFD.
+/**
+ * Open a communication channel to the IFD.
  */
-
 LONG IFDOpenIFD(PREADER_CONTEXT rContext)
 {
 	RESPONSECODE rv = 0;
@@ -184,11 +182,9 @@ LONG IFDOpenIFD(PREADER_CONTEXT rContext)
 	return rv;
 }
 
-/*
- * Function: IFDCloseIFD Purpose : This function closes a communication
- * channel to the IFD.
+/**
+ * Close a communication channel to the IFD.
  */
-
 LONG IFDCloseIFD(PREADER_CONTEXT rContext)
 {
 	RESPONSECODE rv = IFD_SUCCESS;
@@ -207,7 +203,9 @@ LONG IFDCloseIFD(PREADER_CONTEXT rContext)
 	 * LOCK THIS CODE REGION
 	 */
 
-	SYS_MutexLock(rContext->mMutex);
+	rv = SYS_MutexTryLock(rContext->mMutex);
+	if (EBUSY == rv)
+		Log1(PCSC_LOG_ERROR, "Locking failed");
 #ifndef PCSCLITE_STATIC_DRIVER
 	if (rContext->dwVersion == IFD_HVERSION_1_0)
 
@@ -229,11 +227,9 @@ LONG IFDCloseIFD(PREADER_CONTEXT rContext)
 	return rv;
 }
 
-/*
- * Function: IFDSetCapabilites Purpose : This function set's capabilities
- * in the reader.
+/**
+ * Set capabilities in the reader.
  */
-
 LONG IFDSetCapabilities(PREADER_CONTEXT rContext, DWORD dwTag,
 			DWORD dwLength, PUCHAR pucValue)
 {
@@ -271,12 +267,11 @@ LONG IFDSetCapabilities(PREADER_CONTEXT rContext, DWORD dwTag,
 	return rv;
 }
 
-/*
- * Function: IFDGetCapabilites Purpose : This function get's capabilities
- * in the reader. Other functions int this file will call the driver
- * directly to not cause a deadlock.
+/**
+ * Get's capabilities in the reader.
+ * Other functions int this file will call
+ * the driver directly to not cause a deadlock.
  */
-
 LONG IFDGetCapabilities(PREADER_CONTEXT rContext, DWORD dwTag,
 	PDWORD pdwLength, PUCHAR pucValue)
 {
@@ -323,11 +318,9 @@ LONG IFDGetCapabilities(PREADER_CONTEXT rContext, DWORD dwTag,
 	return rv;
 }
 
-/*
- * Function: IFDPowerICC Purpose : This function powers up/down or reset's
- * an ICC located in the IFD.
+/**
+ * Power up/down or reset's an ICC located in the IFD.
  */
-
 LONG IFDPowerICC(PREADER_CONTEXT rContext, DWORD dwAction,
 	PUCHAR pucAtr, PDWORD pdwAtrLen)
 {
@@ -423,12 +416,10 @@ LONG IFDPowerICC(PREADER_CONTEXT rContext, DWORD dwAction,
 	return rv;
 }
 
-/*
- * Function: IFDStatusICC Purpose : This function provides statistical
- * information about the IFD and ICC including insertions, atr, powering
- * status/etc.
+/**
+ * Provide statistical information about the IFD and ICC including insertions,
+ * atr, powering status/etc.
  */
-
 LONG IFDStatusICC(PREADER_CONTEXT rContext, PDWORD pdwStatus,
 	PUCHAR pucAtr, PDWORD pdwAtrLen)
 {
@@ -621,10 +612,9 @@ LONG IFDControl_v2(PREADER_CONTEXT rContext, PUCHAR TxBuffer,
 	}
 }
 
-/*
- * Function: IFDControl Purpose : This function provides a means for
- * toggling a specific action on the reader such as swallow, eject,
- * biometric.
+/**
+ * Provide a means for toggling a specific action on the reader such as
+ * swallow, eject, biometric.
  */
 
 /*
@@ -683,11 +673,9 @@ LONG IFDControl(PREADER_CONTEXT rContext, DWORD ControlCode,
 	}
 }
 
-/*
- * Function: IFDTransmit Purpose : This function transmits an APDU to the
- * ICC.
+/**
+ * Transmit an APDU to the ICC.
  */
-
 LONG IFDTransmit(PREADER_CONTEXT rContext, SCARD_IO_HEADER pioTxPci,
 	PUCHAR pucTxBuffer, DWORD dwTxLength, PUCHAR pucRxBuffer,
 	PDWORD pdwRxLength, PSCARD_IO_HEADER pioRxPci)
