@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: readerfactory.c 2636 2007-10-11 08:15:43Z rousseau $
+ * $Id: readerfactory.c 2975 2008-05-29 13:47:03Z rousseau $
  */
 
 /**
@@ -245,53 +245,38 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 	rv = RFInitializeReader(sReadersContexts[dwContext]);
 	if (rv != SCARD_S_SUCCESS)
 	{
-		/*
-		 * Cannot connect to reader exit gracefully
-		 */
-		/*
-		 * Clean up so it is not using needed space
-		 */
+		/* Cannot connect to reader. Exit gracefully */
 		Log2(PCSC_LOG_ERROR, "%s init failed.", lpcReader);
-
-		(sReadersContexts[dwContext])->dwVersion = 0;
-		(sReadersContexts[dwContext])->dwPort = 0;
-		(sReadersContexts[dwContext])->vHandle = NULL;
-		(sReadersContexts[dwContext])->readerState = NULL;
-		(sReadersContexts[dwContext])->dwIdentity = 0;
-
-		/*
-		 * Destroy and free the mutex
-		 */
-		if (*(sReadersContexts[dwContext])->pdwMutex == 1)
-		{
-			SYS_MutexDestroy((sReadersContexts[dwContext])->mMutex);
-			free((sReadersContexts[dwContext])->mMutex);
-		}
-
-		*(sReadersContexts[dwContext])->pdwMutex -= 1;
-
-		if (*(sReadersContexts[dwContext])->pdwMutex == 0)
-		{
-			free((sReadersContexts[dwContext])->pdwMutex);
-			(sReadersContexts[dwContext])->pdwMutex = NULL;
-		}
-
-		*(sReadersContexts[dwContext])->pdwFeeds -= 1;
-
-		if (*(sReadersContexts[dwContext])->pdwFeeds == 0)
-		{
-			free((sReadersContexts[dwContext])->pdwFeeds);
-			(sReadersContexts[dwContext])->pdwFeeds = NULL;
-		}
-
-		dwNumReadersContexts -= 1;
-
+		RFRemoveReader(lpcReader, dwPort);
 		return rv;
 	}
 
-	rv = EHSpawnEventHandler(sReadersContexts[dwContext]);
-	if (rv != SCARD_S_SUCCESS)
-		return rv;
+	/*
+	 * asynchronous card movement?
+	 */
+	{
+		RESPONSECODE (*fct)(DWORD) = NULL;
+
+		dwGetSize = sizeof(fct);
+
+		rv = IFDGetCapabilities((sReadersContexts[dwContext]),
+			TAG_IFD_POLLING_THREAD, &dwGetSize, (PUCHAR)&fct);
+		if ((rv != SCARD_S_SUCCESS) || (dwGetSize != sizeof(fct)))
+		{
+			fct = NULL;
+			Log1(PCSC_LOG_INFO, "Using the pcscd polling thread");
+		}
+		else
+			Log1(PCSC_LOG_INFO, "Using the reader polling thread");
+
+		rv = EHSpawnEventHandler(sReadersContexts[dwContext], fct);
+		if (rv != SCARD_S_SUCCESS)
+		{
+			Log2(PCSC_LOG_ERROR, "%s init failed.", lpcReader);
+			RFRemoveReader(lpcReader, dwPort);
+			return rv;
+		}
+	}
 
 	/*
 	 * Call on the driver to see if there are multiple slots
@@ -327,6 +312,7 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 	{
 		char *tmpReader = NULL;
 		DWORD dwContextB = 0;
+		RESPONSECODE (*fct)(DWORD) = NULL;
 
 		/*
 		 * We must find an empty spot to put the
@@ -344,7 +330,7 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 		if (i == PCSCLITE_MAX_READERS_CONTEXTS)
 		{
 			/*
-			 * No more spots left return
+			 * No more slot left return
 			 */
 			rv = RFRemoveReader(lpcReader, dwPort);
 			return SCARD_E_NO_MEMORY;
@@ -422,51 +408,31 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 		rv = RFInitializeReader(sReadersContexts[dwContextB]);
 		if (rv != SCARD_S_SUCCESS)
 		{
-			/*
-			 * Cannot connect to slot exit gracefully
-			 */
-			/*
-			 * Clean up so it is not using needed space
-			 */
-			Log2(PCSC_LOG_ERROR, "%s init failed.", lpcReader);
-
-			(sReadersContexts[dwContextB])->dwVersion = 0;
-			(sReadersContexts[dwContextB])->dwPort = 0;
-			(sReadersContexts[dwContextB])->vHandle = NULL;
-			(sReadersContexts[dwContextB])->readerState = NULL;
-			(sReadersContexts[dwContextB])->dwIdentity = 0;
-
-			/*
-			 * Destroy and free the mutex
-			 */
-			if (*(sReadersContexts[dwContextB])->pdwMutex == 1)
-			{
-				SYS_MutexDestroy((sReadersContexts[dwContextB])->mMutex);
-				free((sReadersContexts[dwContextB])->mMutex);
-			}
-
-			*(sReadersContexts[dwContextB])->pdwMutex -= 1;
-
-			if (*(sReadersContexts[dwContextB])->pdwMutex == 0)
-			{
-				free((sReadersContexts[dwContextB])->pdwMutex);
-				(sReadersContexts[dwContextB])->pdwMutex = NULL;
-			}
-
-			*(sReadersContexts[dwContextB])->pdwFeeds -= 1;
-
-			if (*(sReadersContexts[dwContextB])->pdwFeeds == 0)
-			{
-				free((sReadersContexts[dwContextB])->pdwFeeds);
-				(sReadersContexts[dwContextB])->pdwFeeds = NULL;
-			}
-
-			dwNumReadersContexts -= 1;
-
+			/* Cannot connect to slot. Exit gracefully */
+			RFRemoveReader(lpcReader, dwPort);
 			return rv;
 		}
 
-		EHSpawnEventHandler(sReadersContexts[dwContextB]);
+		/* asynchronous card movement? */
+		dwGetSize = sizeof(fct);
+
+		rv = IFDGetCapabilities((sReadersContexts[dwContextB]),
+				TAG_IFD_POLLING_THREAD, &dwGetSize, (PUCHAR)&fct);
+		if ((rv != SCARD_S_SUCCESS) || (dwGetSize != sizeof(fct)))
+		{
+			fct = NULL;
+			Log1(PCSC_LOG_INFO, "Using the pcscd polling thread");
+		}
+		else
+			Log1(PCSC_LOG_INFO, "Using the reader polling thread");
+
+		rv = EHSpawnEventHandler(sReadersContexts[dwContextB], fct);
+		if (rv != SCARD_S_SUCCESS)
+		{
+			Log2(PCSC_LOG_ERROR, "%s init failed.", lpcReader);
+			RFRemoveReader(lpcReader, dwPort);
+			return rv;
+		}
 	}
 
 	return SCARD_S_SUCCESS;
@@ -1596,7 +1562,7 @@ void RFAwakeAllReaders(void)
 			}
 
 
-			EHSpawnEventHandler(sReadersContexts[i]);
+			EHSpawnEventHandler(sReadersContexts[i], NULL);
 			RFSetReaderEventState(sReadersContexts[i], SCARD_RESET);
 		}
 	}
