@@ -4,7 +4,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: sys_generic.h 2076 2006-06-07 12:58:14Z rousseau $
+ * $Id: sys_generic.h 2264 2006-12-03 13:15:03Z rousseau $
  */
 
 /**
@@ -25,7 +25,7 @@ extern "C"
 
 	int SYS_Initialize(void);
 
-	int SYS_Mkdir(char *, int);
+	int SYS_Mkdir(const char *, int);
 
 	int SYS_GetPID(void);
 
@@ -33,39 +33,27 @@ extern "C"
 
 	int SYS_USleep(int);
 
-	int SYS_OpenFile(char *, int, int);
+	int SYS_OpenFile(const char *, int, int);
 
 	int SYS_CloseFile(int);
 
-	int SYS_RemoveFile(char *);
+	int SYS_RemoveFile(const char *);
 
 	int SYS_Chmod(const char *, int);
 
 	int SYS_Chdir(const char *);
 
-	int SYS_Mkfifo(const char *, int);
-
-	int SYS_Mknod(const char *, int, int);
-
 	int SYS_GetUID(void);
 
 	int SYS_GetGID(void);
 
-	int SYS_Chown(const char *, int, int);
-
-	int SYS_ChangePermissions(char *, int);
-
-	int SYS_LockFile(int);
-
-	int SYS_LockAndBlock(int);
-
-	int SYS_UnlockFile(int);
+	int SYS_ChangePermissions(const char *, int);
 
 	int SYS_SeekFile(int, int);
 
 	int SYS_ReadFile(int, char *, int);
 
-	int SYS_WriteFile(int, char *, int);
+	int SYS_WriteFile(int, const char *, int);
 
 	int SYS_GetPageSize(void);
 
@@ -81,11 +69,7 @@ extern "C"
 
 	int SYS_Daemon(int, int);
 
-	int SYS_Wait(int, int);
-
-	int SYS_Stat(char *pcFile, struct stat *psStatus);
-
-	int SYS_Fstat(int);
+	int SYS_Stat(const char *pcFile, struct stat *psStatus);
 
 	int SYS_RandomInt(int, int);
 
@@ -93,9 +77,7 @@ extern "C"
 
 	void SYS_Exit(int);
 
-	int SYS_Rmdir(char *pcFile);
-
-	int SYS_Unlink(char *pcFile);
+	int SYS_Unlink(const char *pcFile);
 
 #ifdef __cplusplus
 }
