@@ -6,7 +6,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: sys_unix.c 2403 2007-02-19 09:16:29Z rousseau $
+ * $Id: sys_unix.c 2778 2008-02-01 09:35:05Z rousseau $
  */
 
 /**
@@ -203,7 +203,12 @@ INTERNAL int SYS_WriteFile(int iHandle, const char *pcBuffer, int iLength)
  */
 INTERNAL int SYS_GetPageSize(void)
 {
-	return getpagesize();
+	static int size = -1;
+
+	/* we use a cache to avoid a system call and improve perfs */
+	if (-1 == size)
+		size = getpagesize();
+	return size;
 }
 
 /**
