@@ -3,10 +3,10 @@
  *
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 2004-2006
+ * Copyright (C) 2004-2008
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: testpcsc.c 2706 2007-11-17 20:01:43Z rousseau $
+ * $Id: testpcsc.c 3021 2008-06-24 09:59:35Z rousseau $
  */
 
 /**
@@ -25,7 +25,15 @@
 
 #define PANIC 0
 #define DONT_PANIC 1
-#define RED_PRINTF_FORMAT "\33[01;31m%s\33[0m\n"
+
+#define USE_AUTOALLOCATE
+
+#define BLUE "\33[34m"
+#define RED "\33[31m"
+#define BRIGHT_RED "\33[01;31m"
+#define GREEN "\33[32m"
+#define NORMAL "\33[0m"
+#define MAGENTA "\33[35m"
 
 void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic);
 void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
@@ -33,10 +41,10 @@ void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
 	if (rv != SCARD_S_SUCCESS)
 	{
 		if (dont_panic)
-			printf("\33[34m%s (don't panic)\33[0m\n", pcsc_stringify_error(rv));
+			printf(BLUE "%s (don't panic)\n" NORMAL, pcsc_stringify_error(rv));
 		else
 		{
-			printf(RED_PRINTF_FORMAT, pcsc_stringify_error(rv));
+			printf(RED "%s\n" NORMAL, pcsc_stringify_error(rv));
 			SCardReleaseContext(hContext);
 			exit(-1);
 		}
@@ -51,11 +59,13 @@ int main(int argc, char **argv)
 	SCARDCONTEXT hContext;
 	SCARD_READERSTATE_A rgReaderStates[1];
 	DWORD dwReaderLen, dwState, dwProt, dwAtrLen;
-	DWORD dwPref, dwReaders;
+	DWORD dwPref, dwReaders = 0;
 	char *pcReaders, *mszReaders;
 	unsigned char pbAtr[MAX_ATR_SIZE];
+	unsigned char *pbAttr = NULL;
+	DWORD pcbAttrLen;
 	char *mszGroups;
-	DWORD dwGroups;
+	DWORD dwGroups = 0;
 	long rv;
 	DWORD i;
 	int p, iReader;
@@ -68,8 +78,8 @@ int main(int argc, char **argv)
 
 	printf("\nMUSCLE PC/SC Lite unitary test Program\n\n");
 
-	printf("\33[35mTHIS PROGRAM IS NOT DESIGNED AS A TESTING TOOL FOR END USERS!\n");
-	printf("Do NOT use it unless you really know what you do.\33[0m\n\n");
+	printf(MAGENTA "THIS PROGRAM IS NOT DESIGNED AS A TESTING TOOL FOR END USERS!\n");
+	printf("Do NOT use it unless you really know what you do.\n\n" NORMAL);
 
 	printf("Testing SCardEstablishContext\t: ");
 	rv = SCardEstablishContext(SCARD_SCOPE_SYSTEM, NULL, NULL, &hContext);
@@ -90,44 +100,63 @@ int main(int argc, char **argv)
 	test_rv(rv, hContext, PANIC);
 
 	printf("Testing SCardListReaderGroups\t: ");
-	rv = SCardListReaderGroups(hContext, 0, &dwGroups);
+#ifdef USE_AUTOALLOCATE
+	dwGroups = SCARD_AUTOALLOCATE;
+	rv = SCardListReaderGroups(hContext, (LPSTR)&mszGroups, &dwGroups);
+#else
+	rv = SCardListReaderGroups(hContext, NULL, &dwGroups);
 	test_rv(rv, hContext, PANIC);
 
-	mszGroups = malloc(sizeof(char) * dwGroups);
+	printf("Testing SCardListReaderGroups\t: ");
+	mszGroups = calloc(dwGroups, sizeof(char));
 	rv = SCardListReaderGroups(hContext, mszGroups, &dwGroups);
+#endif
 	test_rv(rv, hContext, PANIC);
 
 	/*
 	 * Have to understand the multi-string here
 	 */
 	p = 0;
-	for (i = 0; i < dwGroups - 1; i++)
+	for (i = 0; i+1 < dwGroups; i++)
 	{
 		++p;
-		printf("Group %02d: %s\n", p, &mszGroups[i]);
-		iList[p] = i;
+		printf(GREEN "Group %02d: %s\n" NORMAL, p, &mszGroups[i]);
 		while (mszGroups[++i] != 0) ;
 	}
 
+#ifdef USE_AUTOALLOCATE
+	printf("Testing SCardFreeMemory\t\t: ");
+	rv = SCardFreeMemory(hContext, mszGroups);
+	test_rv(rv, hContext, PANIC);
+#else
+	free(mszGroups);
+#endif
+
 wait_for_card_again:
 	printf("Testing SCardListReaders\t: ");
 
 	mszGroups = NULL;
-	rv = SCardListReaders(hContext, mszGroups, 0, &dwReaders);
+#ifdef USE_AUTOALLOCATE
+	dwReaders = SCARD_AUTOALLOCATE;
+	rv = SCardListReaders(hContext, mszGroups, (LPSTR)&mszReaders, &dwReaders);
+#else
+	rv = SCardListReaders(hContext, mszGroups, NULL, &dwReaders);
 	test_rv(rv, hContext, PANIC);
 
-	mszReaders = malloc(sizeof(char) * dwReaders);
+	printf("Testing SCardListReaders\t: ");
+	mszReaders = calloc(dwReaders, sizeof(char));
 	rv = SCardListReaders(hContext, mszGroups, mszReaders, &dwReaders);
+#endif
 	test_rv(rv, hContext, PANIC);
 
 	/*
 	 * Have to understand the multi-string here
 	 */
 	p = 0;
-	for (i = 0; i < dwReaders - 1; i++)
+	for (i = 0; i+1 < dwReaders; i++)
 	{
 		++p;
-		printf("Reader %02d: %s\n", p, &mszReaders[i]);
+		printf(GREEN "Reader %02d: %s\n" NORMAL, p, &mszReaders[i]);
 		iList[p] = i;
 		while (mszReaders[++i] != 0) ;
 	}
@@ -193,10 +222,10 @@ wait_for_card_again:
 	rv = SCardTransmit(hCard, &pioSendPci, bSendBuffer, send_length,
 		&pioRecvPci, bRecvBuffer, &length);
 	printf("%s\n", pcsc_stringify_error(rv));
-	printf(" card response:");
+	printf(" card response:" GREEN);
 	for (i=0; i<length; i++)
 		printf(" %02X", bRecvBuffer[i]);
-	printf("\n");
+	printf("\n" NORMAL);
 
 	printf("Testing SCardControl\t\t: ");
 #ifdef PCSC_PRE_120
@@ -224,28 +253,48 @@ wait_for_card_again:
 	test_rv(rv, hContext, DONT_PANIC);
 
 	printf("Testing SCardGetAttrib\t\t: ");
-	rv = SCardGetAttrib(hCard, SCARD_ATTR_ATR_STRING, NULL, &dwAtrLen);
-	test_rv(rv, hContext, DONT_PANIC);
-	if (rv == SCARD_S_SUCCESS)
-		printf("ATR length: %ld\n", dwAtrLen);
-
-	printf("Testing SCardGetAttrib\t\t: ");
-	dwAtrLen = sizeof(pbAtr);
-	rv = SCardGetAttrib(hCard, SCARD_ATTR_ATR_STRING, pbAtr, &dwAtrLen);
+#ifdef USE_AUTOALLOCATE
+	pcbAttrLen = SCARD_AUTOALLOCATE;
+	rv = SCardGetAttrib(hCard, SCARD_ATTR_ATR_STRING, (unsigned char *)&pbAttr,
+		&pcbAttrLen);
+#else
+	rv = SCardGetAttrib(hCard, SCARD_ATTR_ATR_STRING, NULL, &pcbAttrLen);
 	test_rv(rv, hContext, DONT_PANIC);
 	if (rv == SCARD_S_SUCCESS)
 	{
-		for (i = 0; i < dwAtrLen; i++)
-			printf("%02X ", pbAtr[i]);
-		printf("\n");
+		printf("SCARD_ATTR_ATR_STRING length: " GREEN "%ld\n" NORMAL, pcbAttrLen);
+		pbAttr = malloc(pcbAttrLen);
 	}
 
+	printf("Testing SCardGetAttrib\t\t: ");
+	rv = SCardGetAttrib(hCard, SCARD_ATTR_ATR_STRING, pbAttr, &pcbAttrLen);
+#endif
+	test_rv(rv, hContext, DONT_PANIC);
+	if (rv == SCARD_S_SUCCESS)
+	{
+		printf("SCARD_ATTR_ATR_STRING length: " GREEN "%ld\n" NORMAL, pcbAttrLen);
+		printf("SCARD_ATTR_ATR_STRING: " GREEN);
+		for (i = 0; i < pcbAttrLen; i++)
+			printf("%02X ", pbAttr[i]);
+		printf("\n" NORMAL);
+	}
+
+#ifdef USE_AUTOALLOCATE
+	printf("Testing SCardFreeMemory\t\t: ");
+	rv = SCardFreeMemory(hContext, pbAttr);
+	test_rv(rv, hContext, PANIC);
+#else
+	if (pbAttr)
+		free(pbAttr);
+#endif
+
 	printf("Testing SCardGetAttrib\t\t: ");
 	dwAtrLen = sizeof(pbAtr);
 	rv = SCardGetAttrib(hCard, SCARD_ATTR_VENDOR_IFD_VERSION, pbAtr, &dwAtrLen);
 	test_rv(rv, hContext, DONT_PANIC);
 	if (rv == SCARD_S_SUCCESS)
-		printf("Vendor IFD version\t\t: 0x%08lX\n", ((DWORD *)pbAtr)[0]);
+		printf("Vendor IFD version\t\t: " GREEN "0x%08lX\n" NORMAL,
+			((DWORD *)pbAtr)[0]);
 
 	printf("Testing SCardGetAttrib\t\t: ");
 	dwAtrLen = sizeof(pbAtr);
@@ -254,9 +303,10 @@ wait_for_card_again:
 	if (rv == SCARD_S_SUCCESS)
 	{
 		if (dwAtrLen == sizeof(uint32_t))
-			printf("Max message length\t\t: %d\n", *(uint32_t *)pbAtr);
+			printf("Max message length\t\t: " GREEN "%d\n" NORMAL,
+				*(uint32_t *)pbAtr);
 		else
-			printf(RED_PRINTF_FORMAT, "Wrong size");
+			printf(RED "Wrong size" NORMAL);
 	}
 
 	printf("Testing SCardGetAttrib\t\t: ");
@@ -264,7 +314,7 @@ wait_for_card_again:
 	rv = SCardGetAttrib(hCard, SCARD_ATTR_VENDOR_NAME, pbAtr, &dwAtrLen);
 	test_rv(rv, hContext, DONT_PANIC);
 	if (rv == SCARD_S_SUCCESS)
-		printf("Vendor name\t\t\t: %s\n", pbAtr);
+		printf("Vendor name\t\t\t: " GREEN "%s\n" NORMAL, pbAtr);
 
 	printf("Testing SCardSetAttrib\t\t: ");
 	rv = SCardSetAttrib(hCard, SCARD_ATTR_ATR_STRING, (LPCBYTE)"", 1);
@@ -280,17 +330,18 @@ wait_for_card_again:
 		pbAtr, &dwAtrLen);
 	test_rv(rv, hContext, PANIC);
 
-	printf("Current Reader Name\t\t: %s\n", pcReaders);
-	printf("Current Reader State\t\t: 0x%.4lx\n", dwState);
-	printf("Current Reader Protocol\t\t: T=%ld\n", dwProt - 1);
-	printf("Current Reader ATR Size\t\t: %ld bytes\n", dwAtrLen);
-	printf("Current Reader ATR Value\t: ");
+	printf("Current Reader Name\t\t: " GREEN "%s\n" NORMAL, pcReaders);
+	printf("Current Reader State\t\t: " GREEN "0x%.4lx\n" NORMAL, dwState);
+	printf("Current Reader Protocol\t\t: T=" GREEN "%ld\n" NORMAL, dwProt - 1);
+	printf("Current Reader ATR Size\t\t: " GREEN "%ld" NORMAL " bytes\n",
+		dwAtrLen);
+	printf("Current Reader ATR Value\t: " GREEN);
 
 	for (i = 0; i < dwAtrLen; i++)
 	{
 		printf("%02X ", pbAtr[i]);
 	}
-	printf("\n");
+	printf(NORMAL "\n");
 
 	if (rv != SCARD_S_SUCCESS)
 	{
@@ -309,6 +360,14 @@ wait_for_card_again:
 	rv = SCardDisconnect(hCard, SCARD_UNPOWER_CARD);
 	test_rv(rv, hContext, PANIC);
 
+#ifdef USE_AUTOALLOCATE
+	printf("Testing SCardFreeMemory\t\t: ");
+	rv = SCardFreeMemory(hContext, mszReaders);
+	test_rv(rv, hContext, PANIC);
+#else
+	free(mszReaders);
+#endif
+
 	printf("Testing SCardReleaseContext\t: ");
 	rv = SCardReleaseContext(hContext);
 	test_rv(rv, hContext, PANIC);
