@@ -4,9 +4,10 @@
  * Copyright (C) 2000-2004
  *  David Corcoran <corcoran@linuxnet.com>
  *  Damien Sauveron <damien.sauveron@labri.fr>
+ * Copyright (C) 2000-2008
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: thread_unix.c 2654 2007-10-16 14:23:20Z rousseau $
+ * $Id: thread_unix.c 2962 2008-05-16 09:32:19Z rousseau $
  */
 
 /**
@@ -19,76 +20,85 @@
 #include "thread_generic.h"
 #include "misc.h"
 
-#ifndef TRUE
-#define TRUE 1
-#define FALSE 0
-#endif
-
 INTERNAL int SYS_MutexInit(PCSCLITE_MUTEX_T mMutex)
 {
-	return pthread_mutex_init(mMutex, NULL);
+	if (mMutex)
+		return pthread_mutex_init(mMutex, NULL);
+	else
+		return -1;
 }
 
 INTERNAL int SYS_MutexDestroy(PCSCLITE_MUTEX_T mMutex)
 {
-	return pthread_mutex_destroy(mMutex);
+	if (mMutex)
+		return pthread_mutex_destroy(mMutex);
+	else
+		return -1;
 }
 
 INTERNAL int SYS_MutexLock(PCSCLITE_MUTEX_T mMutex)
 {
-	return pthread_mutex_lock(mMutex);
+	if (mMutex)
+		return pthread_mutex_lock(mMutex);
+	else
+		return -1;
+}
+
+INTERNAL int SYS_MutexTryLock(PCSCLITE_MUTEX_T mMutex)
+{
+	if (mMutex)
+		return pthread_mutex_trylock(mMutex);
+	else
+		return -1;
 }
 
 INTERNAL int SYS_MutexUnLock(PCSCLITE_MUTEX_T mMutex)
 {
-	return pthread_mutex_unlock(mMutex);
+	if (mMutex)
+		return pthread_mutex_unlock(mMutex);
+	else
+		return -1;
 }
 
 INTERNAL int SYS_ThreadCreate(PCSCLITE_THREAD_T * pthThread, int attributes,
 	PCSCLITE_THREAD_FUNCTION(pvFunction), LPVOID pvArg)
 {
 	pthread_attr_t attr;
-	int ret = FALSE;
+	int ret;
 
-	if (0 != pthread_attr_init(&attr))
-		return FALSE;
+	ret = pthread_attr_init(&attr);
+	if (ret)
+		return ret;
 
-	if (0 != pthread_attr_setdetachstate(&attr,
-		attributes & THREAD_ATTR_DETACHED ? PTHREAD_CREATE_DETACHED : PTHREAD_CREATE_JOINABLE))
+	ret = pthread_attr_setdetachstate(&attr,
+		attributes & THREAD_ATTR_DETACHED ? PTHREAD_CREATE_DETACHED : PTHREAD_CREATE_JOINABLE);
+	if (ret)
 	{
 		pthread_attr_destroy(&attr);
-		return FALSE;
+		return ret;
 	}
 
-	if (0 == pthread_create(pthThread, &attr, pvFunction, pvArg))
-		ret = TRUE;
+	ret = pthread_create(pthThread, &attr, pvFunction, pvArg);
+	if (ret)
+		return ret;
 
-	pthread_attr_destroy(&attr);
+	ret = pthread_attr_destroy(&attr);
 	return ret;
 }
 
 INTERNAL int SYS_ThreadCancel(PCSCLITE_THREAD_T pthThread)
 {
-	if (0 == pthread_cancel(pthThread))
-		return TRUE;
-	else
-		return FALSE;
+	return pthread_cancel(pthThread);
 }
 
 INTERNAL int SYS_ThreadDetach(PCSCLITE_THREAD_T pthThread)
 {
-	if (0 == pthread_detach(pthThread))
-		return TRUE;
-	else
-		return FALSE;
+	return pthread_detach(pthThread);
 }
 
-INTERNAL int SYS_ThreadJoin(PCSCLITE_THREAD_T *pthThread, LPVOID* pvRetVal)
+INTERNAL int SYS_ThreadJoin(PCSCLITE_THREAD_T pthThread, LPVOID* pvRetVal)
 {
-	if (0 == pthread_join(*pthThread, pvRetVal))
-		return TRUE;
-	else
-		return FALSE;
+	return pthread_join(pthThread, pvRetVal);
 }
 
 INTERNAL int SYS_ThreadExit(LPVOID pvRetVal)
@@ -107,3 +117,8 @@ INTERNAL int SYS_ThreadEqual(PCSCLITE_THREAD_T *pthThread1, PCSCLITE_THREAD_T *p
 	return pthread_equal(*pthThread1, *pthThread2);
 }
 
+INTERNAL int SYS_ThreadSetCancelType(int type, int *oldtype)
+{
+	return pthread_setcanceltype(type, oldtype);
+}
+
