@@ -10,10 +10,12 @@
 #ifndef __utils_h__
 #define __utils_h__
 
+#include <sys/types.h>
 #include "wintypes.h"
 
 #define PID_ASCII_SIZE 11
 pid_t GetDaemonPid(void);
+int SendHotplugSignal(void);
 
 /* defined in winscard_clnt.c */
 LONG SCardCheckDaemonAvailability(void);
