@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_svc.c 2635 2007-10-09 15:01:07Z rousseau $
+ * $Id: winscard_svc.c 3031 2008-06-27 07:31:37Z rousseau $
  */
 
 /**
@@ -34,7 +34,7 @@
 #include "readerfactory.h"
 
 /**
- * @brief Represents the an Application Context on the Server side.
+ * @brief Represents an Application Context on the Server side.
  *
  * An Application Context contains Channels (\c hCard).
  */
@@ -42,10 +42,10 @@ static struct _psContext
 {
 	uint32_t hContext;
 	uint32_t hCard[PCSCLITE_MAX_APPLICATION_CONTEXT_CHANNELS];
-	uint32_t dwClientID;			/* Connection ID used to reference the Client. */
-	PCSCLITE_THREAD_T pthThread;		/* Event polling thread's ID */
-	sharedSegmentMsg msgStruct;		/* Msg sent by the Client */
-	int protocol_major, protocol_minor;	/* Protocol number agreed between client and server*/
+	uint32_t dwClientID;			/**< Connection ID used to reference the Client. */
+	PCSCLITE_THREAD_T pthThread;		/**< Event polling thread's ID */
+	sharedSegmentMsg msgStruct;		/**< Msg sent by the Client */
+	int protocol_major, protocol_minor;	/**< Protocol number agreed between client and server*/
 } psContext[PCSCLITE_MAX_APPLICATIONS_CONTEXTS];
 
 LONG MSGCheckHandleAssociation(SCARDHANDLE, DWORD);
@@ -76,7 +76,8 @@ LONG ContextsInitialize(void)
  */
 LONG CreateContextThread(uint32_t *pdwClientID)
 {
-	int i;
+	long i;
+	int rv;
 
 	for (i = 0; i < PCSCLITE_MAX_APPLICATIONS_CONTEXTS; i++)
 	{
@@ -95,13 +96,13 @@ LONG CreateContextThread(uint32_t *pdwClientID)
 		return SCARD_F_INTERNAL_ERROR;
 	}
 
-	if (SYS_ThreadCreate(&psContext[i].pthThread, THREAD_ATTR_DETACHED,
-		(PCSCLITE_THREAD_FUNCTION( )) ContextThread,
-		(LPVOID) i) != 1)
+	rv = SYS_ThreadCreate(&psContext[i].pthThread, THREAD_ATTR_DETACHED,
+		(PCSCLITE_THREAD_FUNCTION( )) ContextThread, (LPVOID) i);
+	if (rv)
 	{
 		SYS_CloseFile(psContext[i].dwClientID);
 		psContext[i].dwClientID = 0;
-		Log1(PCSC_LOG_CRITICAL, "SYS_ThreadCreate failed");
+		Log2(PCSC_LOG_CRITICAL, "SYS_ThreadCreate failed: %s", strerror(rv));
 		return SCARD_E_NO_MEMORY;
 	}
 
@@ -132,7 +133,7 @@ static void ContextThread(LPVOID dwIndex)
 
 	while (1)
 	{
-		switch (rv = SHMProcessEventsContext(&psContext[dwContextIndex].dwClientID, &msgStruct, 0))
+		switch (rv = SHMProcessEventsContext(psContext[dwContextIndex].dwClientID, &msgStruct, 0))
 		{
 		case 0:
 			if (msgStruct.mtype == CMD_CLIENT_DIED)
@@ -153,7 +154,15 @@ static void ContextThread(LPVOID dwIndex)
 				/*
 				 * Command must be found
 				 */
-				MSGFunctionDemarshall(&msgStruct, dwContextIndex);
+				rv = MSGFunctionDemarshall(&msgStruct, dwContextIndex);
+				if (rv)
+				{
+					Log2(PCSC_LOG_DEBUG, "MSGFunctionDemarshall failed: %d",
+						rv);
+					SHMClientCloseSession(psContext[dwContextIndex].dwClientID);
+					MSGCleanupClient(dwContextIndex);
+					SYS_ThreadExit((LPVOID) NULL);
+				}
 
 				/* the SCARD_TRANSMIT_EXTENDED anwser is already sent by
 				 * MSGFunctionDemarshall */
@@ -305,7 +314,7 @@ LONG MSGFunctionDemarshall(psharedSegmentMsg msgStruct, DWORD dwContextIndex)
 
 	case SCARD_CONNECT:
 		coStr = ((connect_struct *) msgStruct->data);
-                
+
 		hCard = coStr->phCard;
 		dwActiveProtocol = coStr->pdwActiveProtocol;
 
@@ -430,7 +439,7 @@ LONG MSGFunctionDemarshall(psharedSegmentMsg msgStruct, DWORD dwContextIndex)
 		gsStr = ((getset_struct *) msgStruct->data);
 		rv = MSGCheckHandleAssociation(gsStr->hCard, dwContextIndex);
 		if (rv != 0) return rv;
-                
+
 		cbAttrLen = gsStr->cbAttrLen;
 
 		gsStr->rv = SCardGetAttrib(gsStr->hCard, gsStr->dwAttrId,
@@ -645,7 +654,7 @@ LONG MSGRemoveContext(SCARDCONTEXT hContext, DWORD dwContextIndex)
 				dwLockId = rContext->dwLockId;
 				rContext->dwLockId = 0;
 
-				if (psContext[dwContextIndex].hCard[i] != dwLockId) 
+				if (psContext[dwContextIndex].hCard[i] != dwLockId)
 				{
 					/*
 					 * if the card is locked by someone else we do not reset it
